***** Multidimensional Poverty using Cross sectional & Panel Data **************

cd "d:\Delft"
use panel_delft, clear

**** See results ************************************************************************

tabstat h_* [aw=weight], by( year)
tabstat a_* [aw=weight], by( year)

**** You can export this results to excell by copy paste the results ****************
**** or installing the command logout (findit logout)********************************* 

logout, save(H) excel replace: tabstat h_* [aw=weight], by( year)
logout, save(A) excel replace: tabstat a_* [aw=weight], by( year)

**** You can calculate the M0 in excel or directly in STATA *********************** 
**** First you need to create a variable to consider the weights ******************

bys year: egen total_w=total(weight) if ci!=.
forvalues x=10(10)100 {
egen MPI_`x'= total(ci*h_`x'*weight/total_w), by(year)
}

**** Using properties of the survey ***************************************************

svyset  cluster [pw= weight], strata( stratum)

**** Calculate the Confidence interval ***********************************************

svy: mean h_10  if year==1996
svy: mean a_10  if year==1996

**** The structure of the data *********************************************************

sort hh_id id year age sex
*br hh_id id year age sex

* defining panel data in stata

tsset id year, yearly delta(5)

**** Probabilities of transition ********************************************************
**** 1996-2001
gen p_entry_1period=(h_10 ==1) if l.h_10 ==0
gen p_exit_1period=(h_10 ==0)  if l.h_10 ==1

**** 2001-2006
gen p_entry_2period=(h_10 ==1) if l2.h_10 ==0
gen p_exit_2period=(h_10 ==0) if l2.h_10 ==1

**** Results
tabstat  p_entry_1period p_exit_1period [aw=weight], by(year)
tabstat  p_entry_2period p_exit_2period [aw=weight], by(sex)
tabstat  p_entry_2period p_exit_2period [aw=weight], by(area)
tabstat  p_entry_2period p_exit_2period [aw=weight], by(HH_status)

**** Probabilities of transition per censored headcount *****************************
gen p_entry_htoilet_1p=(htoilet==1 & h_10==1) if l.htoilet ==0 | l.h_10 ==0
gen p_exit_htoilet_1p=(htoilet==0 | h_10==0) if l.htoilet ==1 &l.h_10 ==1

gen p_entry_htoilet_2p=(htoilet==1 & h_10==1) if l2.htoilet ==0 | l2.h_10 ==0
gen p_exit_htoilet_2p=(htoilet==0 | h_10==0) if l2.htoilet ==1 & l2.h_10 ==1


tabstat   p_entry_htoilet_1p p_exit_htoilet_1p  [aw=weight], by(year)
tabstat   p_entry_htoilet_2p p_exit_htoilet_2p  [aw=weight], by(sex)
tabstat   p_entry_htoilet_2p p_exit_htoilet_2p  [aw=weight], by(are)
tabstat   p_entry_htoilet_2p p_exit_htoilet_2p  [aw=weight], by(HH_status)

**** Exploring new posibilities........ 

* A kind of multidimensional chronic poverty

gen cp_10=h_10 + l.h_10 + l2.h_10
tab cp_10  [aw=weight]

* Changes in the indidual average deprivation

gen dav_1p_10=a_10-l.a_10
gen dav_2p_10=a_10-l2.a_10
tabstat dav_1p_10 [aw=weight], by(year)
tabstat dav_2p_10 [aw=weight]

